@@ -101,31 +101,28 @@ test_that("colormap test some actual colors, based on issue 449b.R", {
           expect_equal(cm$zlim, zlim)
           expect_equal(cm$breaks, seq(38.5, 40.5, 0.1))
           expect_equal(cm$col,
-                       c("#00007F","#0000B4","#0000EA","#0021FF","#0056FF",
-                         "#008CFF","#00C2FF","#00F8FF","#2EFFCF","#64FF99",
-                         "#99FF64","#CFFF2E","#FFF800","#FFC200","#FF8C00",
-                         "#FF5600","#FF2100","#EA0000","#B40000","#7F0000"))
+            c("#440154", "#481467", "#482576", "#453781", "#3F4688", "#39558C",
+              "#32638D", "#2D708E", "#277D8E", "#23898D", "#1F968B", "#1FA286",
+              "#29AF7F", "#3BBB74", "#55C567", "#73D055", "#94D740", "#B8DE28",
+              "#DBE318", "#FDE725"))
           expect_equal(cm$zcol,
-                       c("#7F0000","#7F0000","#7F0000","#7F0000","#7F0000",
-                         "#7F0000","#7F0000","#7F0000","#7F0000","#7F0000",
-                         "#7F0000","#7F0000","#7F0000","#7F0000","#7F0000",
-                         "#B40000","#EA0000","#EA0000","#FF2100","#FF5600",
-                         "#FF8C00","#FFC200","#FFF800","#CFFF2E","#99FF64",
-                         "#64FF99","#2EFFCF","#00F8FF","#00C2FF","#00C2FF",
-                         "#008CFF","#0056FF","#0021FF","#0000EA","#0000B4",
-                         "#00007F","#00007F","#00007F","#00007F","#00007F",
-                         "#00007F","#00007F","#00007F","#00007F","#00007F",
-                         "#00007F","#00007F","#00007F","#00007F","#00007F",
-                         "#00007F","#00007F","#00007F","#00007F","#00007F",
-                         "#00007F","#00007F","#00007F","#00007F","#00007F",
-                         "#00007F","#00007F","#00007F","#00007F","#00007F",
-                         "#0000B4","#0000EA","#0021FF","#0056FF","#008CFF",
-                         "#00C2FF","#00C2FF","#00F8FF","#2EFFCF","#64FF99",
-                         "#99FF64","#CFFF2E","#FFF800","#FFC200","#FF8C00",
-                         "#FF5600","#FF2100","#EA0000","#EA0000","#B40000",
-                         "#7F0000","#7F0000","#7F0000","#7F0000","#7F0000",
-                         "#7F0000","#7F0000","#7F0000","#7F0000","#7F0000",
-                         "#7F0000","#7F0000","#7F0000","#7F0000","#7F0000"))
+            c("#FDE725", "#FDE725", "#FDE725", "#FDE725", "#FDE725", "#FDE725",
+              "#FDE725", "#FDE725", "#FDE725", "#FDE725", "#FDE725", "#FDE725",
+              "#FDE725", "#FDE725", "#FDE725", "#DBE318", "#B8DE28", "#B8DE28",
+              "#94D740", "#73D055", "#55C567", "#3BBB74", "#29AF7F", "#1FA286",
+              "#1F968B", "#23898D", "#277D8E", "#2D708E", "#32638D", "#32638D",
+              "#39558C", "#3F4688", "#453781", "#482576", "#481467", "#440154",
+              "#440154", "#440154", "#440154", "#440154", "#440154", "#440154",
+              "#440154", "#440154", "#440154", "#440154", "#440154", "#440154",
+              "#440154", "#440154", "#440154", "#440154", "#440154", "#440154",
+              "#440154", "#440154", "#440154", "#440154", "#440154", "#440154",
+              "#440154", "#440154", "#440154", "#440154", "#440154", "#481467",
+              "#482576", "#453781", "#3F4688", "#39558C", "#32638D", "#32638D",
+              "#2D708E", "#277D8E", "#23898D", "#1F968B", "#1FA286", "#29AF7F",
+              "#3BBB74", "#55C567", "#73D055", "#94D740", "#B8DE28", "#B8DE28",
+              "#DBE318", "#FDE725", "#FDE725", "#FDE725", "#FDE725", "#FDE725",
+              "#FDE725", "#FDE725", "#FDE725", "#FDE725", "#FDE725", "#FDE725",
+              "#FDE725", "#FDE725", "#FDE725", "#FDE725"))
           expect_equal(cm$missingColor, "gray")
           expect_equal(cm$x0,
                        c(38.6,38.7,38.8,38.9,39.0,39.1,39.2,39.3,39.4,39.5,
@@ -134,15 +131,15 @@ test_that("colormap test some actual colors, based on issue 449b.R", {
                        c(38.6,38.7,38.8,38.9,39.0,39.1,39.2,39.3,39.4,39.5,
                          39.6,39.7,39.8,39.9,40.0,40.1,40.2,40.3,40.4,40.5))
           expect_equal(cm$col0,
-                       c("#00007F","#0000B4","#0000EA","#0021FF","#0056FF",
-                         "#008CFF","#00C2FF","#00F8FF","#2EFFCF","#64FF99",
-                         "#99FF64","#CFFF2E","#FFF800","#FFC200","#FF8C00",
-                         "#FF5600","#FF2100","#EA0000","#B40000","#7F0000"))
+            c("#440154", "#481467", "#482576", "#453781", "#3F4688", "#39558C",
+              "#32638D", "#2D708E", "#277D8E", "#23898D", "#1F968B", "#1FA286",
+              "#29AF7F", "#3BBB74", "#55C567", "#73D055", "#94D740", "#B8DE28",
+              "#DBE318", "#FDE725"))
           expect_equal(cm$col1,
-                       c("#00007F","#0000B4","#0000EA","#0021FF","#0056FF",
-                         "#008CFF","#00C2FF","#00F8FF","#2EFFCF","#64FF99",
-                         "#99FF64","#CFFF2E","#FFF800","#FFC200","#FF8C00",
-                         "#FF5600","#FF2100","#EA0000","#B40000","#7F0000"))
+            c("#440154", "#481467", "#482576", "#453781", "#3F4688", "#39558C",
+              "#32638D", "#2D708E", "#277D8E", "#23898D", "#1F968B", "#1FA286",
+              "#29AF7F", "#3BBB74", "#55C567", "#73D055", "#94D740", "#B8DE28",
+              "#DBE318", "#FDE725"))
 })
 
 test_that("Ex1 from help(colormap)", {
@@ -151,13 +148,13 @@ test_that("Ex1 from help(colormap)", {
           c <- colormap(y)
           expect_equal(c$zlim, c(-1.079124,1.079124), tolerance=0.00001)
           expect_equal(c$breaks[1:3], c(-1.079124, -1.070627, -1.062130), tolerance=0.00001)
-          expect_equal(c$col[1:4], c("#00007F","#000083","#000087","#00008B"))
-          expect_equal(c$zcol[1:4], c("#81FF7C","#C9FF34","#FFE700","#FFA200"))
+          expect_equal(c$col[1:4], c("#440154", "#440256", "#450457", "#450559"))
+          expect_equal(c$zcol[1:4], c("#20918C", "#1FA187", "#2EB37C", "#4AC16C"))
           expect_equal(c$missingColor, "gray")
           expect_equal(c$x0[1:5], c(-1.070627, -1.062130, -1.053633, -1.045136, -1.036639),
                        tolerance=0.00001)
-          expect_equal(c$col0[1:4], c("#00007F","#000083","#000087","#00008B"))
-          expect_equal(c$col1[1:4], c("#00007F","#000083","#000087","#00008B"))
+          expect_equal(c$col0[1:4], c("#440154", "#440256", "#450457", "#450559"))
+          expect_equal(c$col1[1:4], c("#440154", "#440256", "#450457", "#450559"))
           expect_equal(class(c), c("list","colormap"))
 })
 
